==> spey-pyhf-0.1.2.tar.gz: spey-pyhf-0.1.2/README.md <==
# spey-pyhf

[![arxiv](https://img.shields.io/static/v1?style=plastic&label=arXiv&message=2307.06996&color=brightgreen)](https://arxiv.org/abs/2307.06996)
[![DOI](https://img.shields.io/static/v1?style=plastic&label=DOI&message=TBA&color=blue)]()
[![zenodo](https://zenodo.org/badge/617041391.svg)](https://zenodo.org/doi/10.5281/zenodo.10493271)
[![doc](https://img.shields.io/static/v1?style=plastic&label&message=Documentation&logo=gitbook&logoColor=white&color=gray)](http://spey-pyhf.readthedocs.io/)

[![github](https://img.shields.io/static/v1?style=plastic&label&message=GitHub&logo=github&logoColor=black&color=white)](https://github.com/SpeysideHEP/spey-pyhf)
[![pypi](https://img.shields.io/static/v1?style=plastic&label&message=pypi&logo=python&logoColor=yellow&color=blue)](https://pypi.org/project/spey-pyhf/)
[![Documentation Status](https://readthedocs.org/projects/spey-pyhf/badge/?version=main&style=plastic)](https://spey-pyhf.readthedocs.io)

``pyhf`` plugin for spey interface can be found in [PyPi library](https://pypi.org/project/spey-pyhf/) and can be downloaded using

```bash
python -m pip install spey-pyhf
```

command. Once installed ``spey`` interface will be able to automatically detect it.
For details on usage please see the [online documentation](http://spey-pyhf.readthedocs.io/).

If you like to use a specific branch you can either use `make install` or `pip install -e .` after cloning the repository or use the following command

```bash
python -m pip install --upgrade "git+https://github.com/SpeysideHEP/spey-pyhf"
```

**Note that `main` branch may not be the stable version.**

==> spey-pyhf-0.1.3.tar.gz: spey-pyhf-0.1.3/README.md <==
# spey-pyhf

[![arxiv](https://img.shields.io/static/v1?style=plastic&label=arXiv&message=2307.06996&color=brightgreen&logo=arXiv)](https://arxiv.org/abs/2307.06996)
[![DOI](https://img.shields.io/static/v1?style=plastic&label=DOI&message=TBA&color=blue)]()
[![DOI](https://zenodo.org/badge/617041391.svg)](https://zenodo.org/doi/10.5281/zenodo.10493271)
[![doc](https://img.shields.io/static/v1?style=plastic&label&message=Documentation&logo=gitbook&logoColor=white&color=gray)](http://spey-pyhf.readthedocs.io/)

[![github](https://img.shields.io/static/v1?style=plastic&label&message=GitHub&logo=github&logoColor=black&color=white)](https://github.com/SpeysideHEP/spey-pyhf)
[![PyPI - Version](https://img.shields.io/pypi/v/spey-pyhf?style=plastic)](https://pypi.org/project/spey-pyhf/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/spey-pyhf?style=plastic&link=https%3A%2F%2Fpypi.org%2Fproject%2Fspey-pyhf)](https://pypi.org/project/spey-pyhf/)
[![Documentation Status](https://readthedocs.org/projects/spey-pyhf/badge/?version=main&style=plastic)](https://spey-pyhf.readthedocs.io)
[![GitHub License](https://img.shields.io/github/license/SpeysideHEP/spey-pyhf?style=plastic)](https://github.com/SpeysideHEP/spey-pyhf/blob/main/LICENSE)

``pyhf`` plugin for spey interface can be found in [PyPi library](https://pypi.org/project/spey-pyhf/) and can be downloaded using

```bash
python -m pip install spey-pyhf
```

command. Once installed ``spey`` interface will be able to automatically detect it.
For details on usage please see the [online documentation](http://spey-pyhf.readthedocs.io/).

If you like to use a specific branch you can either use `make install` or `pip install -e .` after cloning the repository or use the following command

```bash
python -m pip install --upgrade "git+https://github.com/SpeysideHEP/spey-pyhf"
```

**Note that `main` branch may not be the stable version.**
